@@ -48,29 +48,71 @@ def scaffold(conda, package, entry_point, empty):
     template = '-e/--entry-point is not compatible with the {flag} flag'
 
     if entry_point and conda:
-        raise click.ClickException(template.format(flag='--conda'))
+        err = template.format(flag='--conda')
+        telemetry.log_api("scaffold_error",
+                          metadata={
+                              'type': 'entry_and_conda_flag',
+                              'exception': err,
+                              'argv': sys.argv
+                          })
+        raise click.ClickException(err)
 
     if entry_point and package:
-        raise click.ClickException(template.format(flag='--package'))
+        err = template.format(flag='--package')
+        telemetry.log_api("scaffold_error",
+                          metadata={
+                              'type': 'entry_and_package_flag',
+                              'exception': err,
+                              'argv': sys.argv
+                          })
+        raise click.ClickException(err)
 
     if entry_point and empty:
-        raise click.ClickException(template.format(flag='--empty'))
+        err = template.format(flag='--empty')
+        telemetry.log_api("scaffold_error",
+                          metadata={
+                              'type': 'entry_and_empty_flag',
+                              'exception': err,
+                              'argv': sys.argv
+                          })
+        raise click.ClickException(err)
 
     # try to load a dag by looking in default places
-    if not entry_point:
+    if entry_point is None:
         loaded = _scaffold.load_dag()
     else:
         try:
-            loaded = DAGSpec(entry_point,
-                             lazy_import='skip'), Path(entry_point)
+            loaded = (
+                DAGSpec(entry_point, lazy_import='skip'),
+                Path(entry_point).parent,
+                Path(entry_point),
+            )
         except Exception as e:
+            telemetry.log_api("scaffold_error",
+                              metadata={
+                                  'type': 'dag_load_failed',
+                                  'exception': e,
+                                  'argv': sys.argv
+                              })
             raise click.ClickException(e) from e
 
     if loaded:
-        # add scaffold tasks
-        spec, path_to_spec = loaded
+        # existing pipeline, add tasks
+        spec, _, path_to_spec = loaded
         _scaffold.add(spec, path_to_spec)
+        telemetry.log_api("ploomber_scaffold",
+                          dag=loaded,
+                          metadata={
+                              'type': 'add_task',
+                              'argv': sys.argv
+                          })
     else:
+        # no pipeline, create base project
+        telemetry.log_api("ploomber_scaffold",
+                          metadata={
+                              'type': 'base_project',
+                              'argv': sys.argv
+                          })
         scaffold_project.cli(project_path=None,
                              conda=conda,
                              package=package,
@@ -105,6 +147,12 @@ def examples(name, force, branch, output):
     except click.ClickException:
         raise
     except Exception as e:
+        telemetry.log_api("examples_error",
+                          metadata={
+                              'type': 'runtime_error',
+                              'exception': e,
+                              'argv': sys.argv
+                          })
         raise RuntimeError(
             'An error happened when executing the examples command. Check out '
             'the full error message for details. Downloading the examples '
@@ -114,6 +162,11 @@ def examples(name, force, branch, output):
             'Update [conda]: conda update ploomber -c conda-forge') from e
 
 
+def _exit_with_error_message(msg):
+    click.echo(msg, err=True)
+    sys.exit(2)
+
+
 def cmd_router():
     cmd_name = None if len(sys.argv) < 2 else sys.argv[1]
 
@@ -127,6 +180,9 @@ def cmd_router():
         'nb': cli_module.nb.main,
     }
 
+    # users may attempt to run execute/run, suggest to use build instead
+    alias = {'execute': 'build', 'run': 'build'}
+
     if cmd_name in custom:
         # NOTE: we don't use the argument here, it is parsed by _main
         # pop the second element ('entry') to make the CLI behave as expected
@@ -136,8 +192,21 @@ def cmd_router():
         sys.path.insert(0, os.path.abspath('.'))
         fn = custom[cmd_name]
         fn()
+    elif cmd_name in alias:
+        suggestion = alias[cmd_name]
+        telemetry.log_api("unsupported_build_cmd",
+                          metadata={
+                              'cmd_name': cmd_name,
+                              'suggestion': suggestion,
+                              'argv': sys.argv
+                          })
+        _exit_with_error_message("Try 'ploomber --help' for help.\n\n"
+                                 f"Error: {cmd_name!r} is not a valid command."
+                                 f" Did you mean {suggestion!r}?")
     else:
-        telemetry.log_api("unsupported-api-call", metadata={'argv': sys.argv})
+        if cmd_name not in ['examples', 'scaffold']:
+            telemetry.log_api("unsupported-api-call",
+                              metadata={'argv': sys.argv})
         cli()
 
 
