@@ -1,3 +1,5 @@
+import sys
+
 from ploomber.cli.parsers import CustomParser
 from ploomber.cli.io import cli_endpoint
 from ploomber.util.default import extract_name
@@ -9,7 +11,7 @@ from ploomber.telemetry import telemetry
 @cli_endpoint
 def main():
     start_time = datetime.datetime.now()
-    parser = CustomParser(description='Plot a pipeline')
+    parser = CustomParser(description='Plot a pipeline', prog='ploomber plot')
     with parser:
         parser.add_argument(
             '--output',
@@ -27,5 +29,7 @@ def main():
     dag.plot(output=output)
     end_time = datetime.datetime.now()
     telemetry.log_api("ploomber_plot",
-                      total_runtime=str(end_time - start_time))
+                      total_runtime=str(end_time - start_time),
+                      dag=dag,
+                      metadata={'argv': sys.argv})
     print('Plot saved at:', output)
